#
# spec file for package verilator
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           verilator
Version:        4.228
Release:        1.4
Summary:        Compiling Verilog HDL simulator
License:        Artistic-2.0 OR LGPL-3.0-only
Group:          Productivity/Scientific/Electronics
URL:            https://www.veripool.org/projects/verilator/wiki/Intro
Source0:        https://github.com/verilator/verilator/archive/refs/tags/v%{version}.tar.gz#/verilator-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gdb
BuildRequires:  perl
BuildRequires:  pkgconfig

%description
Verilator compiles synthesizable Verilog (not test-bench code), plus
some PSL, SystemVerilog and Synthesis assertions into an optimized
model which is in turn wrapped inside a C++/SystemC module for faster
execution.

%package devel
Summary:        Verilator library header files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
BuildArch:      noarch

%description devel
Development files for Verilator, a compiling Verilog HDL simulator.
It includes header files and a pkgconfig file.

%package        examples
Summary:        Examples for verilator
Group:          Documentation/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description    examples
Verilator is a compiling Verilog HDL simulator.

This package contains examples of using verilator.

%prep
%setup -q
# Use real path in she-bangs
sed -i -e '1 s@bin/env perl@bin/perl@' bin/*
sed -i -e '1 s@bin/env python3@bin/python3@' bin/*

%build
autoconf
%configure
%make_build

%install
%make_install

# install examples
install -d %{buildroot}%{_docdir}/%{name}/
mv %{buildroot}%{_datadir}/verilator/examples %{buildroot}%{_docdir}/%{name}/examples

# fix install of devel files
mkdir -p %{buildroot}%{_includedir}/
mv %{buildroot}%{_datadir}/verilator/include/ %{buildroot}%{_includedir}/verilator

%check
mkdir -p "~/.config/gdb/"
echo "set auto-load safe-path /" > "~/.config/gdb/gdbinit"
export DEBUGINFOD_URLS=""
make test

%files
%license Artistic LICENSE
%doc Changes README.rst
%exclude %{_docdir}/%{name}/examples/
%{_bindir}/verilator
%{_bindir}/verilator_bin
%{_bindir}/verilator_bin_dbg
%{_bindir}/verilator_coverage
%{_bindir}/verilator_coverage_bin_dbg
%{_bindir}/verilator_gantt
%{_bindir}/verilator_profcfunc
%{_datadir}/verilator
%{_mandir}/man1/verilator.1%{?ext_man}
%{_mandir}/man1/verilator_coverage.1%{?ext_man}

%files devel
%{_datadir}/pkgconfig/verilator.pc
%{_includedir}/verilator

%files examples
%doc %{_docdir}/%{name}/examples/

%changelog
* Sat Oct 29 2022 Dirk Müller <dmueller@suse.com>
- update to 4.228:
  * Support some IEEE signal strengths
  * Add --main to generate main() C++
  * Add --build-jobs, and rework arguments for -j
  * Rename --bin to --build-dep-bin
  * Rename debug flags --dumpi-tree, --dumpi-graph, etc.
  * Fix thread saftey in SystemC VL_ASSIGN_SBW/WSB
  * Fix crash in gate optimization of circular logic
  * Fix arguments in non-static method call
  * Fix default --mod-prefix when --prefix is repeated
  * Fix calling trace() after open() segfault
  * Fix typedef'ed class conversion to boolean
  * Fix Verilation speed when disabled warnings
  * Add --future0 and --future1 options
  * Support class parameters
  * Support wildcard index associative arrays
  * Support negated properties
  * Support $test$plusargs(expr)
  * Rename trace rolloverSize()
  * Improve Verilation speed with --threads on large designs.
  * Improve Verilation memory by reducing V3Number
  * Fix struct pattern assignment
  * Fix public combo propagation issues
  * Fix incorrect tristate logic (#3399)
  * Fix incorrect bit op tree optimization
  * Fix bisonpre for MSYS2
  * Fix max memory usage
  * Fix empty string arguments to display
  * Fix table misoptimizing away display
  * Fix unique_ptr memory header for MinGW64
  * Fix $dump systemtask with --output-split-cfuncs
  * Fix wrong bit op tree optimization
  * Fix nested default assignment for struct pattern
  * Fix sformat string incorrectly cleared
  * Fix segfault exporting non-existant package
  * Fix void-cast queue pop_front or pop_back
  * Fix case statement comparing string literal
  * Fix === with some tristate constants
  * Fix converting subclasses to string
  * Fix --hierarchical with order-based pin connections
  * VCD tracing is now parallelized with --threads
  * Add -f<optimization> options to replace -O<letter> options
  * Changed --no-merge-const-pool to -fno-merge-const-pool
  * Changed --no-decoration to remove output whitespace
  * Support compile time trace signal selection with tracing_on/off
  * Support non-ANSI interface port declarations
  * Support concat assignment to packed array
  * Improve conditional merging optimization
  * Define VM_TRACE_VCD when tracing in VCD format.
  * Add assert when VerilatedContext is mis-deleted
  * Internal prep work towards timing control.
  * Fix hang with large case statement optimization
  * Fix UNOPTFLAT warning from initial static var
  * Fix compile error when enable VL_LEAK_CHECKS
  * Fix cmake rules to support higher-level targets
  * Fix BLKANDNBLK on $readmem/$writemem
  * Fix 'with' operator with type casting
  * Fix incorrect conditional merging
  * Fix passing VL_TRACE_FST_WRITER_THREAD in CMake build.
  * Fix compile error under strict C++11 mode
  * Fix public unpacked input ports [Todd Strader]
* Tue Jun  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 4.222. For a list of changes, see included Changes or
  https://github.com/verilator/verilator/blob/v4.222/Changes
- See https://verilator.org/guide/latest/ for documentation
- Remove obsolete verilator-rpmlintrc
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.202. Changes since 4.200:
  * Documentation has been rewritten into a book format.
  * Verilated signals now use VlWide and VlPacked in place of C
    arrays.
  * Add an URL on warnings to point to the manual's description.
  * Add EOFNEWLINE warning when missing a newline at EOF.
  * Changed TIMESCALEMOD from error into a warning.
  * Mark --no-relative-cfuncs as scheduled for deprecation.
  * Add --coverage-max-width.
  * Add VerilatedCovContext::forcePerInstance.
  * Add FST SystemC tracing.
  * Add PINNOTFOUND warning in place of error.
  * Support overlaps in priority case statements.
  * Support for null ports.
  * Fix class unpacked-array compile error.
  * Fix scope types in FST and VCD traces.
  * Fix exceeding command-line ar limit.
  * Fix false $dumpfile warning on model save.
  * Fix --timescale-override not suppressing TIMESCALEMOD.
  * Fix false TIMESCALEMOD on generate-ignored instances.
  * Fix --output-split with class extends.
  * Fix false WIDTHCONCAT on casted constant.
  * Fix tracing of long hashed names.
  * Fix --public-flat-rw / DPI issue.
  * Fix interface localparam access.
  * Fix Cygwin example compile issues.
  * Fix select of with index variable.
  * Fix cmake version number to be numeric.
  * Fix MinGW not supportting 'localtime_r'.
  * Fix cast from packed, typedef'ed interface signal.
  * Fix VPI package reported as vpiModule.
  * Fix dumping waveforms to multiple FST files.
  * Fix assertion failure in bitOpTree.
  * Fix V3Premit infinite loop on always read-and-write.
  * Fix VPI packed vectors.
  * Fix VPI public interface parameters.
  * Check the Changes file for older changes
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- update to 4.108:
  * Many VPI changes for IEEE compatibility, which may alter
    behavior from previous releases.
  * Support randomize() class method and rand
  * Support $cast and new CASTCONST warning.
  * Add --top option as alias of --top-module.
  * Add LATCH and NOLATCH warnings
  * Remove Unix::Processors internal test dependency.
  * Report UNUSED on parameters, localparam and genvars
  * Add error on real to non-real output pins
  * Support package imports before parameters in interfaces
  * Support --sanitize in internal tests
  * Fix passing parameter type instantiations by position number.
  * Fix DPI open array handling issues.
  * Fix error when dotted refers to missing module
  * Fix little endian packed array counting
  * Fix showing reference locations for BLKANDNBLK
  * Fix genblk naming to match IEEE
  * Fix VPI memory word indexing
  * Fix vpiLeftRange on little-endian memories
  * Fix VPI module tree
  * Fix vpi_release_handle to be called implicitly per IEEE
  * Fix to allow inheriting 'VerilatedVcdFile' class.
  * Fix $urandom_range maximum value
  * Fix to emit timescale in hierarchical blocks
  * Fix to ignore coverage on real ports
* Sat Jan  2 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.106 (see included Changes file for details)
- Remove add-shebangs.patch, just mangle she-bang with sed
* Tue Feb 12 2019 John Vandenberg <jayvdb@gmail.com>
- Update to version 4.010 (see included Changes file for details)
- Add add-shebangs.patch to add shebangs to executable scripts
- Move development files into devel subpackage
* Thu Dec  6 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.008 (see included Changes file for details)
- Remove SystemPerl dependency, no longer supported since version 3.910
* Sat Jul  7 2018 david.lanzendoerfer@o2s.ch
- Update to version 3.904 (see Changes)
* Thu Feb 16 2017 jengelh@inai.de
- Rewrite description to give more insight as to what it does.
* Sun Feb  5 2017 aloisio@gmx.com
- Update to version 3.900 (see Changes)
* Sun Aug 17 2014 dmitry_r@opensuse.org
- Initial package, version 3.862
- Add verilator-rpmlintrc to avoid warnings about source files for
  SystemC
